@@ -10,7 +10,7 @@ import os.path as op
 
 import wx
 
-from . import run_with_wx
+from . import run_with_wx, realYield
 
 import fsleyes_widgets.imagepanel as ip
 
@@ -26,8 +26,12 @@ def _test_ImagePanel():
     icon = wx.Bitmap(icon,  wx.BITMAP_TYPE_PNG)
     icon = icon.ConvertToImage()
 
-    frame = wx.GetApp().GetTopWindow()
-    panel = ip.ImagePanel(frame)
-    wx.Yield()
-    panel.SetImage(icon)
-    wx.Yield()
+    frame  = wx.GetApp().GetTopWindow()
+    panel1 = ip.ImagePanel(frame)
+    realYield()
+    panel1.SetImage(icon)
+    realYield()
+    panel2 = ip.ImagePanel(frame, preserveAspect=True)
+    realYield()
+    panel2.SetImage(icon)
+    realYield()
